<p align="center">
    <a href="https://sylius.com" target="_blank">
        <img src="https://demo.sylius.com/assets/shop/img/logo.png" />
    </a>
</p>

<p align="center">
    <a href="https://sylius.com" target="_blank">
        <img src="https://www.dedi-agency.com/wp-content/uploads/2014/05/Dedi_logo_HD.png" />
    </a>
</p>

<h1 align="center">Bonus Points Plugin</h1>

<p align="center">Bonus points plugin for Sylius.</p>

# Use

### Require the plugin with composer :

```bash
composer require dedi/bitbag-sylius-bonus-points-plugin
```

### Import configuration :
```yaml
# config/packages/bitbag_sylius_bonus_points_plugin.yaml
imports:
    # ...
    - { resource: "@BitBagSyliusBonusPointsPlugin/Resources/config/config.yml" }
```

### Import routing :
```yaml
# config/routes.yaml
    # ...
    bitbag_sylius_bonus_points_plugin:
        resource: "@BitBagSyliusBonusPointsPlugin/Resources/config/routing.yml"
    # ...
```

### Add plugin class to your bundles.php :
```php
<?php
$bundles = [
    // ...
    BitBag\SyliusBonusPointsPlugin\BitBagSyliusBonusPointsPlugin::class => ['all' => true],
    // ...
];
```
### Implement BonusPointsAwareInterface on Order :

```php
<?php

# src/Entity/Order.php

declare(strict_types=1);

namespace App\Entity;

use BitBag\SyliusBonusPointsPlugin\Entity\BonusPointsAwareTrait;
use BitBag\SyliusBonusPointsPlugin\Entity\BonusPointsAwareInterface;
use Sylius\Component\Core\Model\Order as BaseOrder;
use Doctrine\ORM\Mapping as ORM;

/**
 * @ORM\Entity
 * @ORM\Table(name="sylius_order")
 */
class Order extends BaseOrder implements BonusPointsAwareInterface
{
    use BonusPointsAwareTrait;
}
```

### Add configuration :
```yaml
sylius_order:
    resources:
        order:
            classes:
                model: App\Entity\Order
```

### Update your database :

```bash
$ bin/console doctrine:migrations:diff
$ bin/console doctrine:migrations:migrate
```

### Install assets :

```bash
$ bin/console assets:install
$ bin/console sylius:theme:assets:install
```

### Clear cache :

```bash
$ bin/console cache:clear
```

### Sylius events

`bitbag_bonus_points.shop.cart.bonus_points` : Adds the bonus points input to the cart summary

```twig
    {# templates/bundles/SyliusShopBundle/Cart/Summary/_items.html.twig #}

    {% if form.bonusPoints is defined %}
        <div class="ui hidden divider"></div>

        {{ sylius_template_event('bitbag_bonus_points.shop.cart.bonus_points', {'cart': cart, 'form': form, 'main_form': form.vars.id}) }}
    {% endif %}
```

### Templates

`@BitBagSyliusBonusPointsPlugin/Shop/Cart/_bonusPoints.html.twig` : bonus points input displayed in the cart summary

# Contribute

## Documentation

For a comprehensive guide on Sylius Plugins development please go to Sylius documentation,
there you will find the <a href="https://docs.sylius.com/en/latest/plugin-development-guide/index.html">Plugin Development Guide</a>, that is full of examples.

## Quickstart Installation

```bash
$ make start
$ make db-create
$ make db-update
$ make fixtures

$ make build
```

## Usage

### Running plugin tests

  - PHPUnit

    ```bash
    $ vendor/bin/phpunit
    ```

  - PHPSpec

    ```bash
    $ vendor/bin/phpspec run
    ```

  - Behat (non-JS scenarios)

    ```bash
    $ vendor/bin/behat --tags="~@javascript"
    ```

  - Behat (JS scenarios)
 
    1. Download [Chromedriver](https://sites.google.com/a/chromium.org/chromedriver/)
    
    2. Download [Selenium Standalone Server](https://www.seleniumhq.org/download/).
    
    2. Run Selenium server with previously downloaded Chromedriver:
    
        ```bash
        $ java -Dwebdriver.chrome.driver=chromedriver -jar selenium-server-standalone.jar
        ```
        
    3. Run test application's webserver on `localhost:8080`:
    
        ```bash
        $ (cd tests/Application && bin/console server:run localhost:8080 -d public -e test)
        ```
    
    4. Run Behat:
    
        ```bash
        $ vendor/bin/behat --tags="@javascript"
        ```

### Opening Sylius with your plugin

- Using `test` environment:

    ```bash
    $ (cd tests/Application && bin/console sylius:fixtures:load -e test)
    $ (cd tests/Application && bin/console server:run -d public -e test)
    ```
    
- Using `dev` environment:

    ```bash
    $ (cd tests/Application && bin/console sylius:fixtures:load -e dev)
    $ (cd tests/Application && bin/console server:run -d public -e dev)
    ```
